@@ -1,7 +1,7 @@
 # ABSTRACT: take structured address data and format it according to the various global/country rules
 
 package Geo::Address::Formatter;
-$Geo::Address::Formatter::VERSION = '1.92';
+$Geo::Address::Formatter::VERSION = '1.93';
 use strict;
 use warnings;
 use feature qw(say);
@@ -142,6 +142,8 @@ sub format_address {
     my $rh_components = clone(shift) || return;
     my $rh_options    = shift        || {};
 
+    # make sure empty at the beginning
+    $self->{final_components} = undef;    
     # deal with the options
     # country
     my $cc
@@ -752,7 +754,7 @@ Geo::Address::Formatter - take structured address data and format it according t
 
 =head1 VERSION
 
-version 1.92
+version 1.93
 
 =head1 SYNOPSIS
 
